<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>러너 설정</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>꾸미기</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>위치:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>보이기:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>기록 먼저 보이기</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>기록 저장하기/보이기</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;알림&lt;/b&gt;: 최상위 위젯의 크기는 데스크톱의 높이와 너비의 2/3로 제한됩니다.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>목록과 함께 보이기:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> 개(s)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>단축키:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>화면 상단 가장자리</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>화면 중앙</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>포커스 된 화면</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>항상 화면 %1에</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>초기화</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>애플리케이션 런처 </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="105"/>
        <source>Configure</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Clear History</source>
        <translation>사용 기록 지우기</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="370"/>
        <source>Show/hide runner dialog</source>
        <translation>러너 대화 상장 보이기/숨기기</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>기록</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
